]> git.parisson.com Git - pdf.js.git/commitdiff
forgot another shadowing
authorAndreas Gal <andreas.gal@gmail.com>
Fri, 13 May 2011 07:21:32 +0000 (00:21 -0700)
committerAndreas Gal <andreas.gal@gmail.com>
Fri, 13 May 2011 07:21:32 +0000 (00:21 -0700)
pdf.js

diff --git a/pdf.js b/pdf.js
index 0461dd34042d6a2a956ea487f2dbf7bcdce252bb..f7d75444c51c1c3766490a2075aaadce678df0e6 100644 (file)
--- a/pdf.js
+++ b/pdf.js
@@ -2002,8 +2002,8 @@ var PDFDoc = (function() {
             var num = linearization
                       ? linearization.numPages
                       : this.catalog.numPages;
-            // overwrite the prototype getter
-            return this.numPages = num;
+            // shadow the prototype getter
+            return shadow(this, "numPages", num);
         },
         getPage: function(n) {
             var linearization = this.linearization;